@@ -1,4 +1,4 @@
-# Load data
+# Load data from 'energyr' package
 data(electric, package = "energyr")
 data(hydropower, package = "energyr")
 data(gas, package = "energyr")
@@ -23,7 +23,9 @@ company <- length(unique(electric[, 1])) + length(unique(hydropower[, "Company"]
 project <- length(unique(pipeline[, "Name"]))
 facility <- length(unique(hydropower[, "Name"])) + length(unique(storage[, "Field"])) + length(unique(lng[, "Company"]))
 
+# Define a server for the app
 shiny::shinyServer(function(input, output, session) {
+
   # Create the projects box
   output$projectBox <- shiny::renderUI({
     shinydashboard::valueBox(
@@ -54,23 +56,52 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the electric rates line chart
   output$lineChart1 <- plotly::renderPlotly({
+
+    # Get the curently selected table rows from the user
     s1 <- input$elecTable_rows_all
+
+    # Subset data based on user selection
     if (length(s1) > 0 && length(s1) < nrow(electric)) {
       electric <- electric[s1, ]
     }
+
+    # Get the rate variable from the user
     if (input$elec == "Revenue") {
       Rate <- electric$Revenue
     } else {
       Rate <- electric$Bill
     }
+
+    # Plot the line chart
     plotly::plot_ly(electric,
-                    x = Year,
-                    y = Revenue,
-                    group = Company)
+                    x = ~Year,
+                    y = ~Rate,
+                    split = ~Company,
+                    type = "scatter") %>%
+
+      # Add style options
+      layout(
+        updatemenus = list(
+          list(
+            buttons = list(
+
+              list(method = "restyle",
+                   args = list("mode", "lines"),
+                   label = "Lines"),
+
+              list(method = "restyle",
+                   args = list("mode", "lines+markers"),
+                   label = "Lines + Markers"),
+
+              list(method = "restyle",
+                   args = list("mode", "markers"),
+                   label = "Markers")))
+        ))
   })
 
   # Show electric rates table
   output$elecTable <- DT::renderDataTable({
+
     DT::datatable(
       electric,
       rownames = FALSE,
@@ -87,7 +118,11 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the hydropower map
   output$map1 <- leaflet::renderLeaflet({
+
+    # Get complete cases from hydropower data
     hydropower <- hydropower[complete.cases(hydropower), ]
+
+    # Create the popup content
     content <- paste0(
       "<strong>Name: </strong>",
       hydropower$Name,
@@ -98,23 +133,37 @@ shiny::shinyServer(function(input, output, session) {
       "<br><strong>Capacity (KW): </strong>",
       hydropower$Capacity
     )
+
+    # Create the color palette
     pal <- leaflet::colorFactor(c("navy", "red"), domain = c("Expired", "Active"))
+
+    # Create the leaflet map
     leaflet::leaflet(hydropower) %>%
+
+      # Manually adjust the bounds of the map
       leaflet::fitBounds(-125, 49,-62, 18) %>%
+
+      # Add provider tiles to the map
       leaflet::addProviderTiles("Esri.WorldStreetMap", group = "World Street Map") %>%
       leaflet::addProviderTiles("CartoDB.DarkMatter", group = "Dark Matter") %>%
       leaflet::addProviderTiles("Esri.WorldImagery", group = "World Imagery") %>%
+
+      # Add circle markers to the map
       leaflet::addCircles(
         radius = ~ sqrt(Capacity / 1000),
         color = ~ pal(Status),
         popup = ~ content
       ) %>%
+
+      # Add a legend to the map
       leaflet::addLegend(
         "topright",
         pal = pal,
         values = ~ Status,
         title = "Status"
       ) %>%
+
+      # Add a control widget to the map
       leaflet::addLayersControl(
         baseGroups = c("World Street Map", "Dark Matter", "World Imagery"),
         position = "bottomright",
@@ -124,9 +173,15 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the hydropower histogram
   output$hist1 <- plotly::renderPlotly({
+
+    # Get the complete cases from hydropower data
     hydropower <- hydropower[complete.cases(hydropower), ]
+
+    # Convert capacity variable
     Capacity <- hydropower$Capacity / 1000
-    plotly::plot_ly(x = Capacity,
+
+    # Plot the histogram
+    plotly::plot_ly(x = ~Capacity,
                     type = "histogram",
                     opacity = 0.75) %>%
       layout(autosize = F,
@@ -136,6 +191,7 @@ shiny::shinyServer(function(input, output, session) {
 
   # Show hydropower data table
   output$hydroTable <- DT::renderDataTable({
+
     DT::datatable(
       hydropower[, 1:9],
       rownames = FALSE,
@@ -151,7 +207,11 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the storage map
   output$map2 <- leaflet::renderLeaflet({
+
+    # Get the complete cases from storage data
     storage <- storage[complete.cases(storage), ]
+
+    # Create the popup content
     content <- paste0(
       "<strong>Company: </strong>",
       storage$Company,
@@ -160,23 +220,36 @@ shiny::shinyServer(function(input, output, session) {
       "<br><strong>Total Capacity (BCF): </strong>",
       storage$Total
     )
+
+    # Create the color palette
     pal <- leaflet::colorFactor(c("navy", "red", "green"),
                            domain = c("Depleted Field", "Salt Dome", "Aquifer"))
+
+    # Plot the leaflet map based on 'Total Capacity' variable
     if (input$storageSize == "Total") {
+
       leaflet::leaflet(storage) %>%
+
+        # Add provider tiles to the map
         leaflet::addProviderTiles("Esri.WorldStreetMap", group = "World Street Map") %>%
         leaflet::addProviderTiles("CartoDB.DarkMatter", group = "Dark Matter") %>%
         leaflet::addProviderTiles("Esri.WorldImagery", group = "World Imagery") %>%
+
+        # Add circle markers to the map
         leaflet::addCircles(
           radius = ~ Total / 1000,
           color = ~ pal(Type),
           popup = ~ content
         ) %>%
+
+        # Add a control widget to the map
         leaflet::addLayersControl(
           baseGroups = c("World Street Map", "Dark Matter", "World Imagery"),
           position = "bottomright",
           options = leaflet::layersControlOptions(collapsed = TRUE)
         ) %>%
+
+        # Add a legend to the map
         leaflet::addLegend(
           "topright",
           pal = pal,
@@ -184,22 +257,31 @@ shiny::shinyServer(function(input, output, session) {
           title = "Storage Type"
         )
 
+      # Plot the leaflet map based on 'Working Capacity' variable
     } else if (input$storageSize == "Working") {
+
       leaflet::leaflet(storage) %>%
+
+        # Add provider tiles to the map
         leaflet::addProviderTiles("Esri.WorldStreetMap", group = "World Street Map") %>%
         leaflet::addProviderTiles("CartoDB.DarkMatter", group = "Dark Matter") %>%
         leaflet::addProviderTiles("Esri.WorldImagery", group = "World Imagery") %>%
+
+        # Add circle markers to the map
         leaflet::addCircles(
           radius = ~ Working / 1000,
           color = ~ pal(Type),
           popup = ~ content
         ) %>%
 
+        # Add a control widget to the map
         leaflet::addLayersControl(
           baseGroups = c("World Street Map", "Dark Matter", "World Imagery"),
           position = "bottomright",
           options = leaflet::layersControlOptions(collapsed = TRUE)
         ) %>%
+
+        # Add a legend to the map
         leaflet::addLegend(
           "topright",
           pal = pal,
@@ -211,13 +293,19 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the storage histogram
   output$hist2 <- plotly::renderPlotly({
+
+    # Get the complete cases from storage data
     storage <- storage[complete.cases(storage), ]
+
+    # Get the selected variable from the user
     if (input$storageSize == "Total") {
       Capacity <- storage$Total / 1000
     } else if (input$storageSize == "Working") {
       Capacity <- storage$Working / 1000
     }
-    plotly::plot_ly(x = Capacity,
+
+    # Plot the histogram
+    plotly::plot_ly(x = ~Capacity,
                     type = "histogram",
                     opacity = 0.75) %>%
       layout(autosize = F,
@@ -227,39 +315,58 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the LNG map
   output$map3 <- leaflet::renderLeaflet({
+
+    # Get the complete cases from lng data
     lng <- lng[complete.cases(lng), ]
+
+    # Create the popup content
     content <- paste0(
       "<strong>Company: </strong>",
       lng$Company,
       "<br><strong>Capacity (BCFD): </strong>",
       lng$Capacity
     )
+
+    # Create the leaflet map based on 'type' variable
     if (input$lngColor == "type") {
+
+      # Create the color palette
       pal <- leaflet::colorFactor(c("navy", "red"), domain = c("Export", "Import"))
+
       leaflet::leaflet(lng) %>%
+
+        # Add provider tiles to the map
         leaflet::addProviderTiles("Esri.WorldStreetMap", group = "World Street Map") %>%
         leaflet::addProviderTiles("CartoDB.DarkMatter", group = "Dark Matter") %>%
         leaflet::addProviderTiles("Esri.WorldImagery", group = "World Imagery") %>%
+
+        # Add circle markers to the map
         leaflet::addCircles(
           radius = ~ Capacity,
           color = ~ pal(Type),
           popup = ~ content
         ) %>%
+
+        # Add a legend to the map
         leaflet::addLegend(
           "topright",
           pal = pal,
           values = ~ Type,
           title = "Facility Type"
         ) %>%
+
+        # Add a control widget to the map
         leaflet::addLayersControl(
           baseGroups = c("World Street Map", "Dark Matter", "World Imagery"),
           position = "bottomright",
           options = leaflet::layersControlOptions(collapsed = TRUE)
         )
+
+      # Create the leaflet map based on 'status' variable
     } else if (input$lngColor == "status") {
-      pal <-
-        leaflet::colorFactor(
-          c("navy", "red", "green", "orange"),
+
+      # Create the color palette
+      pal <- leaflet::colorFactor(c("navy", "red", "green", "orange"),
           domain = c(
             "Not under construction",
             "Under construction",
@@ -267,21 +374,30 @@ shiny::shinyServer(function(input, output, session) {
             "Proposed"
           )
         )
+
       leaflet::leaflet(lng) %>%
+
+        # Add provider tiles to the map
         leaflet::addProviderTiles("Esri.WorldStreetMap", group = "World Street Map") %>%
         leaflet::addProviderTiles("CartoDB.DarkMatter", group = "Dark Matter") %>%
         leaflet::addProviderTiles("Esri.WorldImagery", group = "World Imagery") %>%
+
+        # Add circle markers to the map
         leaflet::addCircles(
           radius = ~ Capacity,
           color = ~ pal(Status),
           popup = ~ content
         ) %>%
+
+        # Add a legend to the map
         leaflet::addLegend(
           "topright",
           pal = pal,
           values = ~ Status,
           title = "Facility Status"
         ) %>%
+
+        # Add a control widget to the map
         leaflet::addLayersControl(
           baseGroups = c("World Street Map", "Dark Matter", "World Imagery"),
           position = "bottomright",
@@ -292,9 +408,15 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the LNG capacity histogram
   output$hist3 <- plotly::renderPlotly({
+
+    # Get the complete cases from lng data
     lng <- lng[complete.cases(lng), ]
+
+    # Get the selected variable from the user
     Capacity <- lng$Capacity
-    plotly::plot_ly(x = Capacity,
+
+    # Plot the histogram
+    plotly::plot_ly(x = ~Capacity,
                     type = "histogram",
                     opacity = 0.75) %>%
       layout(autosize = F,
@@ -304,13 +426,17 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the natural gas pipeline histogram
   output$hist5 <- plotly::renderPlotly({
+
+    # Get the selected variable from the user
     if (input$perform == "costMile") {
-      KPI <- pipeline[, "Cost"] / pipeline[, "Miles"]
+      Cost <- pipeline[, "Cost"] / pipeline[, "Miles"]
     } else if (input$perform == "costCap") {
-      KPI <- pipeline[, "Cost"] / pipeline[, "Capacity"]
+      Cost <- pipeline[, "Cost"] / pipeline[, "Capacity"]
     }
+
+    # Plot the histogram
     plotly::plot_ly(
-      x = KPI,
+      x = ~Cost,
       type = "histogram",
       opacity = 0.75,
       nbinx = 10
@@ -318,28 +444,41 @@ shiny::shinyServer(function(input, output, session) {
   })
 
   # Draw a natural gas pipeline heatmap
-  output$heatmap <- d3heatmap::renderD3heatmap({
+  output$heatmap <- plotly::renderPlotly({
+
+    # Subset data to get numeric variables
     pipeline <- subset(pipeline, select = c("Cost", "Miles", "Capacity"))
+
+    # Get correlation matrix
     dfcor <- cor(pipeline, use = "complete.obs")
+
+    # Get covariance matrix
     dfvar <- dfcor ^ 2 * 100
 
+    # Get the type of heatmap from the user
     if (input$sensitivity == "varr") {
       df <- dfvar
     } else if (input$sensitivity == "corr") {
       df <- dfcor
     }
-    d3heatmap::d3heatmap(
-      df,
-      symm = TRUE,
-      digits = 2,
-      cexRow = 0.8,
-      cexCol = 0.8
+
+    # Plot the heatmap
+    plotly::plot_ly(
+      x = c("Cost", "Miles", "Capacity"),
+      y = c("Cost", "Miles", "Capacity"),
+      z = df,
+      colorscale = "Greys",
+      type = "heatmap"
     )
   })
 
   # Plot the natural gas cost boxplot
   output$boxplot <- plotly::renderPlotly({
+
+    # Omit missing data
     pipeline <- na.omit(pipeline)
+
+    # Get selected variable from the user
     if (input$gas == "cost") {
       cost <- data.frame(Year = pipeline[, "Year"], Cost = pipeline[, "Cost"])
     } else if (input$gas == "costMile") {
@@ -347,27 +486,58 @@ shiny::shinyServer(function(input, output, session) {
     } else if (input$gas == "costCap") {
       cost <- data.frame(Year = pipeline[, "Year"], Cost = pipeline[, "Cost"] / pipeline[, "Capacity"])
     }
+
+    # Plot the boxplot
     plotly::plot_ly(cost,
-                    y = Cost,
-                    group = Year,
+                    y = ~Cost,
+                    split = ~Year,
                     type = "box")
   })
 
   # Plot the natural gas rates line chart
   output$lineChart3 <- plotly::renderPlotly({
+
+    # Get the currently selected table rows from the user
     s2 <- input$gasTable_rows_all
+
+    # Subset data based on user selection
     if (length(s2) > 0 && length(s2) < nrow(gas)) {
       gas <- gas[s2, ]
     }
+
+    # Get the selected variable from the user
     if (input$gasRates == "Revenue") {
       Rate <- gas$Revenue
     } else {
       Rate <- gas$Bill
     }
+
+    # Plot the line chart
     plotly::plot_ly(gas,
-                    x = Year,
-                    y = Rate,
-                    group = Company)
+                    x = ~Year,
+                    y = ~Rate,
+                    split = ~Company,
+                    type = "scatter") %>%
+
+      # Add style options
+      layout(
+        updatemenus = list(
+          list(
+            buttons = list(
+
+              list(method = "restyle",
+                   args = list("mode", "lines"),
+                   label = "Lines"),
+
+              list(method = "restyle",
+                   args = list("mode", "lines+markers"),
+                   label = "Lines + Markers"),
+
+              list(method = "restyle",
+                   args = list("mode", "markers"),
+                   label = "Markers")))
+        ))
+
   })
 
   # Plot the natural gas pipeline motion chart
@@ -378,7 +548,9 @@ shiny::shinyServer(function(input, output, session) {
 
   # Show natural gas pipeline table
   output$pipelineTable <- DT::renderDataTable({
+
     pipeline <- pipeline[, !(names(pipeline) %in% 'Year')]
+
     DT::datatable(
       pipeline[, ],
       rownames = FALSE,
@@ -398,6 +570,7 @@ shiny::shinyServer(function(input, output, session) {
 
   # Show natural gas rates table
   output$gasTable <- DT::renderDataTable({
+
     DT::datatable(
       gas,
       rownames = FALSE,
@@ -414,23 +587,52 @@ shiny::shinyServer(function(input, output, session) {
 
   # Plot the oil rates line chart
   output$lineChart4 <- plotly::renderPlotly({
+
+    # Get the currently selected table rows from the user
     s3 <- input$oilTable_rows_all
+
+    # Subset data based on user selection
     if (length(s3) > 0 && length(s3) < nrow(oil)) {
       oil <- oil[s3, ]
     }
+
+    # Get the type of variable from the user
     if (input$oil == "Revenue") {
       Rate <- oil$Revenue
     } else {
       Rate <- oil$Bill
     }
+
+    # Plot the line chart
     plotly::plot_ly(oil,
-                    x = Year,
-                    y = Rate,
-                    group = Company)
+                    x = ~Year,
+                    y = ~Rate,
+                    split = ~Company,
+                    type = "scatter") %>%
+
+      # Add style options
+      layout(
+        updatemenus = list(
+          list(
+            buttons = list(
+
+              list(method = "restyle",
+                   args = list("mode", "lines"),
+                   label = "Lines"),
+
+              list(method = "restyle",
+                   args = list("mode", "lines+markers"),
+                   label = "Lines + Markers"),
+
+              list(method = "restyle",
+                   args = list("mode", "markers"),
+                   label = "Markers")))
+        ))
   })
 
   # Show oil rates table
   output$oilTable <- DT::renderDataTable({
+
     DT::datatable(
       oil,
       rownames = FALSE,
